import {Component} from '@angular/core'
import {FormBuilder, FormControl, Validators} from '@angular/forms'
import {SubscribingComponent} from '../shared/components/subscribing.component'
import {AccountService} from './services/account.service'
import {AppState} from '../shared/app-state'
import {ErrorService} from '../shared/service/error.service'
import {ActivatedRoute, Router} from '@angular/router'

@Component({
  selector: 'cre-login',
  templateUrl: 'login.html',
  styles: [
    'cre-form { min-width: 25rem; margin-top: 50vh; transform: translateY(-70%) }'
  ]
})
export class Login extends SubscribingComponent {
  userIdControl = new FormControl(null, Validators.compose([Validators.required, Validators.pattern(new RegExp('^[0-9]+$'))]))
  passwordControl = new FormControl(null, Validators.required)

  constructor(
    private formBuilder: FormBuilder,
    private accountService: AccountService,
    private appState: AppState,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
    this.appState.title = 'Connexion'
  }

  submit() {
    this.accountService.login(
      this.userIdControl.value,
      this.passwordControl.value,
      () => this.urlUtils.navigateTo('/color')
    )
  }

  get controls(): { userId: FormControl, password: FormControl } {
    return {
      userId: this.userIdControl,
      password: this.passwordControl
    }
  }
}
